[![MIT
license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

<!-- MarkdownTOC -->

- [Tantrum: Tanium Instrumental API wrapper](#tantrum-tanium-instrumental-api-wrapper)
  - [Installing](#installing)
  - [Examples](#examples)

<!-- /MarkdownTOC -->

# Tantrum: Tanium Instrumental API wrapper

Tantrum is meant to be an API wrapper for [Tanium](https://www.tanium.com). It makes the Tanium API actually usable by providing native python objects for working with API objects, and also provides workflows for complex multi-step operations.

## Installing

Installing tantrum via [pip](https://pypi.org/project/pip/) or [pipenv](https://pipenv.readthedocs.io/en/latest/) will automatically install all of the necessary dependencies.

## Examples

These [examples](examples/) are fairly basic and not intended to be full show & tells. More detailed examples will be added over time.
